@@ -71,7 +71,7 @@ class AcceptanceComputer(strax.Plugin):
     an S2 into small S1 signals that could affect event
     reconstruction).
     """
-    __version__ = '1.0.1'
+    __version__ ='1.0.2'
     depends_on = ('truth', 'truth_matched', 'peak_basics', 'peak_id')
     provides = 'match_acceptance'
     data_kind = 'truth'
@@ -126,8 +126,12 @@ class AcceptanceComputer(strax.Plugin):
         if np.sum(mask):
             # need to get at least one peak for each, even if we are going to remove those later
             sel_peaks = truth[mask]['matched_to']
+            if not np.all(peak_idx[mask] == peaks[sel_peaks]['id']):
+                for t_i, p_i in zip(peak_idx[mask], peaks[sel_peaks]['id']):
+                    print(t_i, p_i)
+                raise ValueError
             for k in self.keep_peak_fields:
-                res[mask][f'rec_{k}'] = peaks[k][sel_peaks]
+                res[f'rec_{k}'][mask] = peaks[k][sel_peaks]
         return res
 
     def infer_dtype(self):
@@ -149,6 +153,7 @@ class AcceptanceComputer(strax.Plugin):
         return dtype
 
 
+
 class AcceptanceExtended(strax.MergeOnlyPlugin):
     """Merge the matched acceptance to the extended truth"""
     __version__ = '0.1.0'
